setwd("/Users/Stephane1/Stat Analyses/Non-Disruptive")

rm(list=ls())

##Summary stats and graphs
library(dplyr)
library (stats)
library (ggplot2)

## Mapping
library(googleVis)
library(forcats)
library(maptools)

##Interaction Networks
library(bipartite)


###########################################################################
#########################    STATS AND GRAPHS    ###########################
###########################################################################

b<-read.table("DataR380.txt", header=T, sep="\t")

head(b)
summary(b)
attach(b)


###########################################################################
######################### Variations through years ###########################

#################Number of papers per year 
#create color palette:
library(RColorBrewer)
coul = brewer.pal(8, "Pastel2") 

qq<-table(b$Date, b$SamplingMethod)
TOTAL<- data.frame("2013"=sum(qq[1,]),"2014"= sum(qq[2,]),"2015"=sum(qq[3,]),"2016"= sum(qq[4,]), "2017"=sum(qq[5,]), "2018"=sum(qq[6,]))

chisq.test(TOTAL)

summary(b$Date)

################# Sampling methods per year 

#Line graphs of each method through years
qq<-table(b$Date, b$SamplingMethod)
#par(mar=c(2,4,2,2))


qq <- qq[,c("Lethal","Non lethal", "Mixed","Vector DNA","DNA trapping", "eDNA" )]
tqq<-t(qq)

Year<-as.integer(rep(c(2013,2014,2015,2016,2017,2018),each=6))
#Sampling_Method<-rep(levels(b$SamplingMethod),6)
Sampling_Method<-rep(row.names(tqq),6)

Value <- as.numeric(tqq)
data <- data.frame(Sampling_Method,Year,Value)

Sampling_Method2 <- fct_relevel(Sampling_Method,"Lethal","Non lethal","Mixed", "Vector DNA","DNA trapping", "eDNA")

ggplot(data, aes(x=Year, y=Value, fill=Sampling_Method2, order = Sampling_Method2))+
  geom_area(position="fill")


#Stacked graph Sampling method through Years FIGURE 1a
cbPalette <- c( "#0072B2","#56B4E9",  "#D55E00", "#CC79A7","#E69F00","#009E73")

ggplot(data, aes(x=Year, y=Value, fill=Sampling_Method2))+
  geom_bar(stat="identity", colour="grey")+
  theme_classic()+
  scale_fill_manual( values=cbPalette)+
  ylab("Number of articles") +
  labs(fill = "Sampling Method" )





################ Compliance through Years

CT<-table(b$Date,b$Compliance_with_T)
tCT<-t(CT)
ComplianceT<-rep(levels(b$Compliance_with_T),6)
Year<-as.integer(rep(c(2013,2014,2015,2016,2017,2018),each=3))
ValueT <- as.numeric(tCT)
dataT <- data.frame(ComplianceT,Year,ValueT)


#Plot simple version
plot(b$Compliance_with_T~b$Date,  col=c("#EA3323","#DE8344","#7EAB55","grey"))
plot(b$Compliance_with_M~b$Date, col=c("#EA3323","#7EAB55","grey"))
DATE<-as.factor(b$Date)
levels (DATE)

#Plot ggplot version
ggplot(dataT, aes(x=Year, y=ValueT, fill=ComplianceT))+
  geom_bar(stat="identity", position="fill")+
  theme_classic()+
  scale_fill_manual( values=c("#EA3323","#DE8344","#7EAB55"))+
  ylab("Proportion of articles") +
  labs(fill = "Compliance" )+
  ggtitle("Compliance through time") 

chisq.test(b$Compliance_with_T,b$Date, correct=FALSE) #X-squared = 17.524, df = 10, p-value = 0.06354



###########################################################################
######################### Titled, Inverts and Contacts ###########################

#########Data  for FIGURE 2a, 2b, 2c (these figures were made on Excel only)

#FiIGURE 2a
#Percentage of studies complying with the different definitions
summary(b$Compliance_with_T)
summary(b$Compliance_with_M)
table(b$Compliance_with_T,b$Noninvasive_in_the_title)


#Non-invasive in the title
summary(b$Noninvasive_in_the_title)
Titled <- b[b$Noninvasive_in_the_title == "YES",]
plot(Titled$Compliance_with_T~Titled$TaxoGroup) 
plot(Titled$Compliance_with_M~Titled$TaxoGroup)
summary(Titled$Compliance_with_T)
summary(Titled$Compliance_with_M)

plot(b$Compliance_with_T~b$Noninvasive_in_the_title)
table(b$Compliance_with_T,b$Noninvasive_in_the_title)

#FiIGURE 2b
summary(b$InvertORVert)
table(b$InvertORVert,b$Compliance_with_T)
table(b$InvertORVert,b$Compliance_with_M)
table(b$TaxoGroup,b$SamplingMethod)
table(b$NatureOfSamples,b$Compliance_with_T)
table(b$SamplingMethod,b$NatureOfSamples)
summary(b$SamplingMethod)
plot(b$SamplingMethod)

#FiIGURE 2c
summary(b$Handling) # 288 not handled or captured or confiscated etc, out of 380 = 76% not handled
plot(b$Handling)
table(b$Compliance_with_T,b$Handling)





###########################################################################
######################### Compliance VS taxonomy ###########################

#FIGURE 2d: Compliance VS Taxonomy

plot(b$Compliance_with_T~b$TaxoGroup) 
plot(b$Compliance_with_M~b$TaxoGroup)
summary(b$Compliance_with_T)
summary(b$Compliance_with_M)

#COLOUR VERSION
cbPalette <- c( "#0072B2","#56B4E9",  "#D55E00", "#CC79A7","#E69F00","#009E73")
plot(b$Compliance_with_T~b$TaxoGroup, col=c("#EA3323","#DE8344","#7EAB55","grey")) 
plot(b$Compliance_with_M~b$TaxoGroup, col=c("#EA3323","#7EAB55","grey"))

plot(b$Compliance_with_T~b$TaxoGroup, col=c("#EA3323","#D55E00", "#009E73")) 



#ggplot(b$Compliance.with.Taberlet~b$Taxo) + theme(axis.text.x = element_text(angle=60, hjust=1))

# Chi-sq test Compliance ~ Taxonomy
chisq.test(b$Compliance_with_T,b$Taxo, correct=FALSE) #X-squared = 165.17, df = 30, p-value < 2.2e-16
chisq.test(b$Compliance_with_M,b$Taxo, correct=FALSE)

#biopsies in mammals vs  fish
levels(b$SamplingMethod)
Biopsies<-b[b$SamplingMethod == "Non lethal",]
plot (Biopsies$TaxoGroup)
plot (b$TaxoGroup)

Bat<-(b[b$TaxoGroup ==  "Bat",])
Bear<-(b[b$TaxoGroup ==  "Bear",])
Canidae<-(b[b$TaxoGroup ==  "Canidae",])
Felidae<-(b[b$TaxoGroup ==  "Felidae",])
Lagomorph<-(b[b$TaxoGroup ==  "Lagomorph",])
Marsupial<-(b[b$TaxoGroup ==  "Marsupial",])
Mustelidae<-(b[b$TaxoGroup ==  "Mustelidae",])
OtherM<-(b[b$TaxoGroup ==  "Other mammals",])
Primate<-(b[b$TaxoGroup ==  "Primate",])
Rodent<-(b[b$TaxoGroup ==  "Rodent",])
Ungulate<-(b[b$TaxoGroup ==  "Ungulate",])

AllMammals<-bind_rows(Bat,Bear,Canidae, Felidae, Lagomorph, Marsupial, Mustelidae,OtherM,Primate, Rodent, Ungulate)
BiopsiesM<-AllMammals[AllMammals$SamplingMethod == "Non lethal",]
plot (BiopsiesM$TaxoGroup) #=9
plot (AllMammals$TaxoGroup) #=279

length (BiopsiesM$TaxoGroup)/length(AllMammals$TaxoGroup) #3.8% of non lethal in mammals


Fish<-(b[b$TaxoGroup ==  "Fish",])
BiopsiesF<-Fish[Fish$SamplingMethod == "Non lethal",]
plot (BiopsiesF$TaxoGroup) #= 6
plot (Fish$TaxoGroup)  #=22
length (BiopsiesF$TaxoGroup)/length(Fish$TaxoGroup) #27.3% of non lethal in Fish





###########################################################################
######################### Sampling Methods and Main Aims  ###########################

#Values from FIGURE 1c ( interaction network): Main aim, nature of samples, sampling method
summary(b$Main_Aim)
plot(b$Main_Aim)
summary(b$NatureOfSamples) #182 feces + 52 mixed that contain feces = 234 in total = 61.57%
plot(b$NatureOfSamples)
plot(b$Compliance_with_T~b$NatureOfSamples, col=c("#EA3323","#DE8344","#7EAB55","grey"))
plot(b$Compliance_with_M~b$NatureOfSamples, col=c("#EA3323","#7EAB55","grey"))


plot(b$Compliance_with_T~b$SamplingMethod)

eDNA<-b[b$SamplingMethod == "eDNA",] 
DNAtrap<-b[b$SamplingMethod == "DNA trapping",]
NonLethal<-b[b$SamplingMethod == "Non lethal",]
Lethal<-b[b$SamplingMethod == "Lethal",]
Mixed<-b[b$SamplingMethod == "Mixed",]
Vector<-b[b$SamplingMethod == "Vector DNA",]

table (eDNA$Main_Aim)
table (DNAtrap$Main_Aim)
table (Lethal$Main_Aim)
table (NonLethal$Main_Aim)
table (Mixed$Main_Aim)
table (Vector$Main_Aim)

table(eDNA$NatureOfSamples)
table(DNAtrap$NatureOfSamples)
table(Lethal$NatureOfSamples)
table(NonLethal$NatureOfSamples)
table(Mixed$NatureOfSamples)


#Sampling methods and fecal sampling
plot(b$Compliance_with_T~b$SamplingMethod)
plot(b$Compliance_with_T~b$NatureOfSamples)

FecesOnly<-b[b$NatureOfSamples =="Feces",]
plot(FecesOnly$Compliance_with_T)
summary(FecesOnly$Compliance_with_T)

levels(b$SamplingMethod)
plot(b$SamplingMethod)
plot(b$Compliance_with_T~b$SamplingMethod)

#DNA trapping with or without baiting
DNAtrap<-b[b$SamplingMethod == "DNA trapping",]  #total = 37, 
DNAtrapB<-DNAtrap[DNAtrap$Compliance_with_T =="non-invasive",] # non baited = 3 + 1 godwin (invasive because of territory but no bait)
#DNAtrapB<-b[b$SamplingMethod == "DNA trapping (baited)",] # baited 

#Mixed methods some may be invasive
levels (b$SamplingMethod)
summary(b$SamplingMethod)
Mixed<-b[b$SamplingMethod =="Mixed",]
summary(Mixed$Compliance_with_T) #31 studies with mixed sampling strategy used non complying methods, only 4 specified which method was non-invasive


#Methods of sampling in relation to compliance
plot(b$Compliance_with_T~b$SamplingMethod)
summary(b$Compliance_with_T~b$SamplingMethod)


###########################################################################
######################### Interaction Networks  ###########################

SampleMethod<-table(b$NatureOfSamples,b$SamplingMethod)
plotweb(SampleMethod)

AimMethod<-table(b$Main_Aim,b$SamplingMethod)
plotweb(AimMethod)


plotweb(SampleMethod,y.width.low=0.1, y.width.high=0.20,
        y.lim=c(0,3), arrow="up", adj.high=c(0.5,1.5), col.high="#E69F00", col.low="#009E73",method="normal",
        high.lablength=15, labsize = 1.6, high.lab.dis=-0.2, low.y=0.8, text.rot=90)

plotweb(t(AimMethod), y.width.low=0.20, y.width.high=0.1,method="normal",
        add=TRUE,low.y=1.5, high.y=2.2, col.high="#0072B2",low.lab.dis=0, arrow="down", 
        labsize = 1.6, adj.low=c(0.5,1.1),low.plot=FALSE, text.rot=90)

#text(0.1,1.5,"DNA trapping")
#text(0.5,1.5,"eDNA")
#text(0.89,1.5,"Lethal")
#text(1,1.5,"Mixed")
#text(1.2,1.5,"Non lethal")
#text(1.28,1.5,"Vector")



###########################################################################
######################### WORLD DISTRIBUTION  ###########################

######### Summary stats
country<-summary(b$Country)
plot(b$Country)


######### Google Map
c<-read.table("CountriesREV.txt", header=T, sep="\t")

occurence<-as.vector(table(c$region))
country<-levels(c$region)
map<-data.frame(country,occurence)

G1a <- gvisGeoChart(map, locationvar='country', colorvar='occurence', options=list(colorAxis="{colors:['CCFFCC', '#339900']}")) 
plot(G1a)
#print(plot(G1a))


######## Quick presence/absence map (not used)
library(maptools)
data(wrld_simpl)
myCountries = wrld_simpl@data$NAME %in% country
plot(wrld_simpl, col = c(gray(.80), "red")[myCountries+1])



